@@ -20,14 +20,14 @@ DERRICK_LOGO = """
 """
 
 DERRICK_HOME = ".derrick"
-DERRICK_APPLICATION_CONF = ".derrick_application_conf"
+DERRICK_APPLICATION_CONF = "derrick_conf"
 RIGGING_HOME = "rigging"
 DERRICK_COMMANDS = "commands"
 
 WORKSPACE_ENV = "WORKSPACE"
 DERRICK_HOME_ENV = "DERRICK_HOME"
 
-DERRICK_VERSION = "0.0.1"
+DERRICK_VERSION = "0.0.2"
 NEW_LINE = "\n"
 FOUR_WHITESPACE = "    "
 COMMANDS_DOC_SECTION = "[COMMANDS_DOC_SECTION]"
